# Popper python package

[![black](https://img.shields.io/badge/code%20style-black-000000.svg)](https://github.com/ambv/black)
[![PyPI version](https://badge.fury.io/py/popper.svg)](https://badge.fury.io/py/popper)

This folder contains the python package Python source code for Popper. 
Read the [Installation Guide](../docs/installation.md) for details on 
how to install Popper, and how to setup a development environment.
